@@ -8,9 +8,10 @@ use Cwd qw/abs_path/;
 use File::Next;
 use File::Basename;
 use File::Path;
+use File::Spec;
 
-my $lib_dir  = abs_path("$Bin/../../lib");
-my $html_dir = abs_path("$Bin/../../docs/pod");
+my $lib_dir = abs_path( File::Spec->catdir( $Bin, '..', '..', 'lib' ) );
+my $html_dir = abs_path( File::Spec->catdir( $Bin, '..', '..', 'docs', 'pod' ) );
 
 my $files = File::Next::files($lib_dir);
 
