@@ -15,7 +15,8 @@ if ( $has_proc_pid_file and $has_home_dir ) {
 }
 
 use FindBin qw/$Bin/;
-use lib "$Bin/../../../lib";
+use File::Spec;
+use lib File::Spec->catdir( $FindBin::Bin, '..', '..', '..', 'lib' );
 use Foorum::SUtils qw/schema/;
 
 my $schema = schema();
